<?php
// $Id: geodata.admin.inc,v 1.1.2.2 2008/10/05 14:41:37 openwereld Exp $

/**
 * Geodata settings form.
 */
function geodata_settings_form() {
  global $db_url;
  
  $form['postgresql'] = array('#type' => 'fieldset'
    , '#title' => t('PostgreSQL')
    , '#collapsible' => TRUE
    );
  
  $form['postgresql']['mappingkit_postgresql_bin_path'] = array('#type' => 'textfield'
    , '#title' => t('Path to PostgreSQL bin folder')
    , '#default_value' => variable_get('mappingkit_postgresql_bin_path', DEFAULT_MAPPINGKIT_POSTGRESQL_BIN_PATH)
    , '#size' => 100
    , '#description' => t('Path to PostgreSQL bin folder without slash at end. This folder should contain programs such as psql and shp2pgsql.')
    , '#validate' => array('geodata_validate_postgresql_bin_path')
    );
  
  $form['geodata'] = array('#type' => 'fieldset'
    , '#title' => t('Databases')
    , '#collapsible' => TRUE
    );

  $form['geodata']['geodata_databases'] = array('#type' => 'textarea'
    , '#title' => t('Databases')
    , '#default_value' => variable_get('geodata_databases', '')
    , '#description' => t("Enter database connection url's for postgis databases in format 'name=user:password@host[:port]/database'. These will be available in addition to the ones defined in the Drupal settings file.")
    , '#rows' => 3
    );
  
  $form['geodata']['geodata_database'] = array('#type' => 'select'
    , '#title' => t('Default database')
    , '#options' => is_array($db_url) ? array_combine(array_keys($db_url), array_keys($db_url)) : array('default' => 'default')
    , '#default_value' => variable_get('geodata_database', DEFAULT_GEODATA_DATABASE)
    , '#description' => t('Select the name of the default database for geodata. This database must have PostGIS enabled.')
    );
  
  $form['#validate'][] = 'geodata_settings_validate';
  $form['#submit'][] = 'geodata_settings_submit';
  
  return system_settings_form($form);
}

/**
 * Validate handler for geodata settings.
 */
function geodata_settings_validate($form, &$form_state) {
  db_set_active($form_state['values']['geodata_database']);
  $table_exists = db_table_exists('spatial_ref_sys');
  db_set_active();
  
  if (! $table_exists) {
    form_set_error('geodata_database', t('Database %name is not PostGIS enabled', array('%name' => $form_state['values']['geodata_database'])));
  }
}

/**
 * Submit handler of geodata settings.
 */
function geodata_settings_submit($form, &$form_state) {
  //drupal_set_message('geodata_settings_submit '. var_export($form_state, true));
  require_once('google_projection.inc.php');
  
  _geodata_add_google_projection($form_state['values']['geodata_database']);
}

function geodata_validate_postgresql_bin_path($form, &$form_state) {
  //drupal_set_message('geodata_validate_postgresql_bin_path');
  if (!file_exists($form_state['values']['mappingkit_postgresql_bin_path'])) {
    form_set_error('mappingkit_postgresql_bin_path', t('Folder %path does not exists.', array('%path' => $form_state['values']['mappingkit_postgresql_bin_path'])));
  }
}

